@@ -7,7 +7,6 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/zricethezav/gitleaks/v8/logging"
-	"github.com/zricethezav/gitleaks/v8/report"
 )
 
 func init() {
@@ -20,27 +19,21 @@ var stdInCmd = &cobra.Command{
 	Run:   runStdIn,
 }
 
-func runStdIn(cmd *cobra.Command, args []string) {
-	initConfig(".")
-	var (
-		findings []report.Finding
-		err      error
-	)
-
-	// setup config (aka, the thing that defines rules)
-	cfg := Config(cmd)
-
+func runStdIn(cmd *cobra.Command, _ []string) {
 	// start timer
 	start := time.Now()
+
+	// setup config (aka, the thing that defines rules)
+	initConfig(".")
+	cfg := Config(cmd)
+
+	// create detector
 	detector := Detector(cmd, cfg, "")
 
-	// set exit code
-	exitCode, err := cmd.Flags().GetInt("exit-code")
-	if err != nil {
-		logging.Fatal().Err(err).Msg("could not get exit code")
-	}
+	// parse flag(s)
+	exitCode := mustGetIntFlag(cmd, "exit-code")
 
-	findings, err = detector.DetectReader(os.Stdin, 10)
+	findings, err := detector.DetectReader(os.Stdin, 10)
 	if err != nil {
 		// log fatal to exit, no need to continue since a report
 		// will not be generated when scanning from a pipe...for now
